@@ -1,13 +1,14 @@
 from typing import Optional, Union
-try:
-    from typing import Literal
-except ImportError:
-    from typing_extensions import Literal
 
 from beartype import beartype
 
 from pglet.control import Control
 
+try:
+    from typing import Literal
+except ImportError:
+    from typing_extensions import Literal
+
 
 DataMode = Literal["default", "fraction", "percentage", None]
 
@@ -16,6 +17,7 @@ class BarChart(Control):
     def __init__(
         self,
         id=None,
+        ref=None,
         tooltips=None,
         data_mode: DataMode = None,
         points=None,
@@ -30,6 +32,7 @@ class BarChart(Control):
         Control.__init__(
             self,
             id=id,
+            ref=ref,
             width=width,
             height=height,
             padding=padding,
@@ -57,7 +60,7 @@ class BarChart(Control):
     # tooltips
     @property
     def tooltips(self):
-        return self._get_attr("tooltips")
+        return self._get_attr("tooltips", data_type="bool", def_value=False)
 
     @tooltips.setter
     @beartype
@@ -79,8 +82,8 @@ class BarChart(Control):
 
 
 class Data(Control):
-    def __init__(self, id=None, points=None):
-        Control.__init__(self, id=id)
+    def __init__(self, id=None, ref=None, points=None):
+        Control.__init__(self, id=id, ref=ref)
 
         self.__points = []
         if points != None:
@@ -107,6 +110,7 @@ class Point(Control):
     def __init__(
         self,
         id=None,
+        ref=None,
         x=None,
         y=None,
         legend=None,
@@ -114,7 +118,7 @@ class Point(Control):
         x_tooltip=None,
         y_tooltip=None,
     ):
-        Control.__init__(self, id=id)
+        Control.__init__(self, id=id, ref=ref)
 
         self.x = x
         self.y = y
