@@ -10,6 +10,7 @@ class Button(Control):
         self,
         text=None,
         id=None,
+        ref=None,
         primary=None,
         compound=None,
         action=None,
@@ -37,6 +38,7 @@ class Button(Control):
         Control.__init__(
             self,
             id=id,
+            ref=ref,
             width=width,
             height=height,
             padding=padding,
@@ -91,7 +93,7 @@ class Button(Control):
     # primary
     @property
     def primary(self):
-        return self._get_attr("primary")
+        return self._get_attr("primary", data_type="bool", def_value=False)
 
     @primary.setter
     @beartype
@@ -101,7 +103,7 @@ class Button(Control):
     # compound
     @property
     def compound(self):
-        return self._get_attr("compound")
+        return self._get_attr("compound", data_type="bool", def_value=False)
 
     @compound.setter
     @beartype
@@ -111,7 +113,7 @@ class Button(Control):
     # action
     @property
     def action(self):
-        return self._get_attr("action")
+        return self._get_attr("action", data_type="bool", def_value=False)
 
     @action.setter
     @beartype
@@ -121,7 +123,7 @@ class Button(Control):
     # toolbar
     @property
     def toolbar(self):
-        return self._get_attr("toolbar")
+        return self._get_attr("toolbar", data_type="bool", def_value=False)
 
     @toolbar.setter
     @beartype
@@ -131,7 +133,7 @@ class Button(Control):
     # split
     @property
     def split(self):
-        return self._get_attr("split")
+        return self._get_attr("split", data_type="bool", def_value=False)
 
     @split.setter
     @beartype
@@ -168,7 +170,7 @@ class Button(Control):
     # new_window
     @property
     def new_window(self):
-        return self._get_attr("newWindow")
+        return self._get_attr("newWindow", data_type="bool", def_value=False)
 
     @new_window.setter
     @beartype
@@ -208,7 +210,7 @@ class Button(Control):
     # focused
     @property
     def focused(self):
-        return self._get_attr("focused")
+        return self._get_attr("focused", data_type="bool", def_value=False)
 
     @focused.setter
     @beartype
@@ -239,6 +241,7 @@ class MenuItem(Control):
         self,
         text=None,
         id=None,
+        ref=None,
         secondary_text=None,
         url=None,
         new_window=None,
@@ -260,6 +263,7 @@ class MenuItem(Control):
         Control.__init__(
             self,
             id=id,
+            ref=ref,
             width=width,
             height=height,
             padding=padding,
@@ -335,7 +339,7 @@ class MenuItem(Control):
     # new_window
     @property
     def new_window(self):
-        return self._get_attr("newWindow")
+        return self._get_attr("newWindow", data_type="bool", def_value=False)
 
     @new_window.setter
     @beartype
@@ -363,7 +367,7 @@ class MenuItem(Control):
     # icon_only
     @property
     def icon_only(self):
-        return self._get_attr("iconOnly")
+        return self._get_attr("iconOnly", data_type="bool", def_value=False)
 
     @icon_only.setter
     @beartype
@@ -373,7 +377,7 @@ class MenuItem(Control):
     # split
     @property
     def split(self):
-        return self._get_attr("split")
+        return self._get_attr("split", data_type="bool", def_value=False)
 
     @split.setter
     @beartype
@@ -383,7 +387,7 @@ class MenuItem(Control):
     # divider
     @property
     def divider(self):
-        return self._get_attr("divider")
+        return self._get_attr("divider", data_type="bool", def_value=False)
 
     @divider.setter
     @beartype
