@@ -1,12 +1,14 @@
 from typing import Optional
+
+from beartype import beartype
+
+from pglet.control import Control
+
 try:
     from typing import Literal
 except:
     from typing_extensions import Literal
 
-from beartype import beartype
-
-from pglet.control import Control
 
 BoxSide = Literal[None, "start", "end"]
 
@@ -16,6 +18,7 @@ class Checkbox(Control):
         self,
         label=None,
         id=None,
+        ref=None,
         value=None,
         value_field=None,
         box_side: BoxSide = None,
@@ -32,6 +35,7 @@ class Checkbox(Control):
         Control.__init__(
             self,
             id=id,
+            ref=ref,
             width=width,
             height=height,
             padding=padding,
@@ -101,7 +105,7 @@ class Checkbox(Control):
     # focused
     @property
     def focused(self):
-        return self._get_attr("focused")
+        return self._get_attr("focused", data_type="bool", def_value=False)
 
     @focused.setter
     @beartype
