@@ -1,12 +1,14 @@
 from typing import Optional
+
+from beartype import beartype
+
+from pglet.control import Control
+
 try:
     from typing import Literal
 except:
     from typing_extensions import Literal
 
-from beartype import beartype
-
-from pglet.control import Control
 
 ItemType = Literal[None, "normal", "divider", "header"]
 
@@ -16,6 +18,7 @@ class Dropdown(Control):
         self,
         label=None,
         id=None,
+        ref=None,
         value=None,
         placeholder=None,
         error_message=None,
@@ -35,6 +38,7 @@ class Dropdown(Control):
         Control.__init__(
             self,
             id=id,
+            ref=ref,
             width=width,
             height=height,
             padding=padding,
@@ -119,7 +123,7 @@ class Dropdown(Control):
     # focused
     @property
     def focused(self):
-        return self._get_attr("focused")
+        return self._get_attr("focused", data_type="bool", def_value=False)
 
     @focused.setter
     @beartype
@@ -146,8 +150,10 @@ class Dropdown(Control):
 
 
 class Option(Control):
-    def __init__(self, key=None, text=None, item_type: ItemType = None, disabled=None):
-        Control.__init__(self)
+    def __init__(
+        self, key=None, text=None, item_type: ItemType = None, disabled=None, ref=None
+    ):
+        Control.__init__(self, ref=ref, disabled=disabled)
         assert key != None or text != None, "key or text must be specified"
         self.key = key
         self.text = text
@@ -184,13 +190,3 @@ class Option(Control):
     @beartype
     def item_type(self, value: ItemType):
         self._set_attr("itemtype", value)
-
-    # disabled
-    @property
-    def disabled(self):
-        return self._get_attr("disabled")
-
-    @disabled.setter
-    @beartype
-    def disabled(self, value: Optional[bool]):
-        self._set_attr("disabled", value)
