@@ -1,14 +1,16 @@
 from __future__ import annotations
 
 from typing import Optional
+
+from beartype import beartype
+
+from pglet.control import Control
+
 try:
     from typing import Literal
 except:
     from typing_extensions import Literal
 
-from beartype import beartype
-
-from pglet.control import Control
 
 SelectionMode = Literal[None, "single", "multiple"]
 Sortable = Literal[None, "string", "number", False]
@@ -19,6 +21,7 @@ class Grid(Control):
     def __init__(
         self,
         id=None,
+        ref=None,
         selection_mode: SelectionMode = None,
         compact=None,
         header_visible=None,
@@ -38,6 +41,7 @@ class Grid(Control):
         Control.__init__(
             self,
             id=id,
+            ref=ref,
             width=width,
             height=height,
             padding=padding,
@@ -127,7 +131,7 @@ class Grid(Control):
     # compact
     @property
     def compact(self):
-        return self._get_attr("compact")
+        return self._get_attr("compact", data_type="bool", def_value=False)
 
     @compact.setter
     @beartype
@@ -137,7 +141,7 @@ class Grid(Control):
     # header_visible
     @property
     def header_visible(self):
-        return self._get_attr("headerVisible")
+        return self._get_attr("headerVisible", data_type="bool", def_value=True)
 
     @header_visible.setter
     @beartype
@@ -147,7 +151,7 @@ class Grid(Control):
     # preserve_selection
     @property
     def preserve_selection(self):
-        return self._get_attr("preserveSelection")
+        return self._get_attr("preserveSelection", data_type="bool", def_value=False)
 
     @preserve_selection.setter
     @beartype
@@ -175,8 +179,8 @@ class Grid(Control):
 
 
 class Columns(Control):
-    def __init__(self, id=None, columns=None):
-        Control.__init__(self, id=id)
+    def __init__(self, id=None, ref=None, columns=None):
+        Control.__init__(self, id=id, ref=ref)
 
         self.columns = columns
 
@@ -188,8 +192,8 @@ class Columns(Control):
 
 
 class Items(Control):
-    def __init__(self, id=None, items=None):
-        Control.__init__(self, id=id)
+    def __init__(self, id=None, ref=None, items=None):
+        Control.__init__(self, id=id, ref=ref)
 
         self.__map = {}
         self.__items = []
@@ -229,6 +233,7 @@ class Column(Control):
     def __init__(
         self,
         id=None,
+        ref=None,
         name=None,
         icon=None,
         icon_only=None,
@@ -242,7 +247,7 @@ class Column(Control):
         on_click=None,
         template_controls=None,
     ):
-        Control.__init__(self, id=id)
+        Control.__init__(self, id=id, ref=ref)
 
         self.name = name
         self.icon = icon
@@ -282,7 +287,7 @@ class Column(Control):
     # icon_only
     @property
     def icon_only(self):
-        return self._get_attr("iconOnly")
+        return self._get_attr("iconOnly", data_type="bool", def_value=False)
 
     @icon_only.setter
     @beartype
@@ -330,7 +335,7 @@ class Column(Control):
     # resizable
     @property
     def resizable(self):
-        return self._get_attr("resizable")
+        return self._get_attr("resizable", data_type="bool", def_value=False)
 
     @resizable.setter
     @beartype
