@@ -1,12 +1,14 @@
 from typing import Optional, Union
+
+from beartype import beartype
+
+from pglet.control import Control
+
 try:
     from typing import Literal
 except:
     from typing_extensions import Literal
 
-from beartype import beartype
-
-from pglet.control import Control
 
 XType = Literal[None, "number", "date"]
 
@@ -15,6 +17,7 @@ class LineChart(Control):
     def __init__(
         self,
         id=None,
+        ref=None,
         legend=None,
         tooltips=None,
         stroke_width=None,
@@ -35,6 +38,7 @@ class LineChart(Control):
         Control.__init__(
             self,
             id=id,
+            ref=ref,
             width=width,
             height=height,
             padding=padding,
@@ -72,7 +76,7 @@ class LineChart(Control):
     # legend
     @property
     def legend(self):
-        return self._get_attr("legend")
+        return self._get_attr("legend", data_type="bool", def_value=False)
 
     @legend.setter
     @beartype
@@ -82,7 +86,7 @@ class LineChart(Control):
     # tooltips
     @property
     def tooltips(self):
-        return self._get_attr("tooltips")
+        return self._get_attr("tooltips", data_type="bool", def_value=False)
 
     @tooltips.setter
     @beartype
@@ -153,8 +157,8 @@ class LineChart(Control):
 
 
 class Data(Control):
-    def __init__(self, id=None, color=None, legend=None, points=None):
-        Control.__init__(self, id=id)
+    def __init__(self, id=None, ref=None, color=None, legend=None, points=None):
+        Control.__init__(self, id=id, ref=ref)
 
         self.color = color
         self.legend = legend
@@ -201,6 +205,7 @@ class Point(Control):
     def __init__(
         self,
         id=None,
+        ref=None,
         x=None,
         y=None,
         tick=None,
@@ -208,7 +213,7 @@ class Point(Control):
         x_tooltip=None,
         y_tooltip=None,
     ):
-        Control.__init__(self, id=id)
+        Control.__init__(self, id=id, ref=ref)
 
         self.x = x
         self.y = y
