@@ -9,6 +9,7 @@ class SearchBox(Control):
     def __init__(
         self,
         id=None,
+        ref=None,
         value=None,
         placeholder=None,
         underlined=None,
@@ -32,6 +33,7 @@ class SearchBox(Control):
         Control.__init__(
             self,
             id=id,
+            ref=ref,
             width=width,
             height=height,
             padding=padding,
@@ -108,7 +110,7 @@ class SearchBox(Control):
     # underlined
     @property
     def underlined(self):
-        return self._get_attr("underlined")
+        return self._get_attr("underlined", data_type="bool", def_value=False)
 
     @underlined.setter
     @beartype
@@ -136,7 +138,7 @@ class SearchBox(Control):
     # focused
     @property
     def focused(self):
-        return self._get_attr("focused")
+        return self._get_attr("focused", data_type="bool", def_value=False)
 
     @focused.setter
     @beartype
