@@ -10,6 +10,7 @@ class Slider(Control):
         self,
         label=None,
         id=None,
+        ref=None,
         value=None,
         min=None,
         max=None,
@@ -32,6 +33,7 @@ class Slider(Control):
         Control.__init__(
             self,
             id=id,
+            ref=ref,
             width=width,
             height=height,
             padding=padding,
@@ -117,7 +119,7 @@ class Slider(Control):
     # show_value
     @property
     def show_value(self):
-        return self._get_attr("showValue")
+        return self._get_attr("showValue", data_type="bool", def_value=False)
 
     @show_value.setter
     @beartype
@@ -136,7 +138,7 @@ class Slider(Control):
     # vertical
     @property
     def vertical(self):
-        return self._get_attr("vertical")
+        return self._get_attr("vertical", data_type="bool", def_value=False)
 
     @vertical.setter
     @beartype
@@ -146,7 +148,7 @@ class Slider(Control):
     # focused
     @property
     def focused(self):
-        return self._get_attr("focused")
+        return self._get_attr("focused", data_type="bool", def_value=False)
 
     @focused.setter
     @beartype
