@@ -2,7 +2,15 @@ from typing import List, Optional
 
 from beartype import beartype
 
-from pglet.control import BorderStyle, Control, TextAlign, TextSize
+from pglet.control import (
+    BorderColor,
+    BorderRadius,
+    BorderStyle,
+    BorderWidth,
+    Control,
+    TextAlign,
+    TextSize,
+)
 
 try:
     from typing import Literal
@@ -18,6 +26,7 @@ class Text(Control):
         self,
         value=None,
         id=None,
+        ref=None,
         markdown=None,
         align: TextAlign = None,
         vertical_align: VerticalAlign = None,
@@ -30,9 +39,9 @@ class Text(Control):
         color=None,
         bgcolor=None,
         border_style: BorderStyle = None,
-        border_width=None,
-        border_color=None,
-        border_radius=None,
+        border_width: BorderWidth = None,
+        border_color: BorderColor = None,
+        border_radius: BorderRadius = None,
         width=None,
         height=None,
         padding=None,
@@ -44,6 +53,7 @@ class Text(Control):
         Control.__init__(
             self,
             id=id,
+            ref=ref,
             width=width,
             height=height,
             padding=padding,
@@ -84,7 +94,7 @@ class Text(Control):
     # markdown
     @property
     def markdown(self):
-        return self._get_attr("markdown")
+        return self._get_attr("markdown", data_type="bool", def_value=False)
 
     @markdown.setter
     @beartype
@@ -124,7 +134,7 @@ class Text(Control):
     # bold
     @property
     def bold(self):
-        return self._get_attr("bold")
+        return self._get_attr("bold", data_type="bool", def_value=False)
 
     @bold.setter
     @beartype
@@ -134,7 +144,7 @@ class Text(Control):
     # italic
     @property
     def italic(self):
-        return self._get_attr("italic")
+        return self._get_attr("italic", data_type="bool", def_value=False)
 
     @italic.setter
     @beartype
@@ -144,7 +154,7 @@ class Text(Control):
     # pre
     @property
     def pre(self):
-        return self._get_attr("pre")
+        return self._get_attr("pre", data_type="bool", def_value=False)
 
     @pre.setter
     @beartype
@@ -154,7 +164,7 @@ class Text(Control):
     # nowrap
     @property
     def nowrap(self):
-        return self._get_attr("nowrap")
+        return self._get_attr("nowrap", data_type="bool", def_value=False)
 
     @nowrap.setter
     @beartype
@@ -164,7 +174,7 @@ class Text(Control):
     # block
     @property
     def block(self):
-        return self._get_attr("block")
+        return self._get_attr("block", data_type="bool", def_value=False)
 
     @block.setter
     @beartype
@@ -192,41 +202,39 @@ class Text(Control):
     # border_style
     @property
     def border_style(self):
-        v = self._get_attr("borderStyle")
-        if v:
-            return [x.strip() for x in v.split(" ")]
-        return v
+        return self._get_value_or_list_attr("borderStyle", " ")
 
     @border_style.setter
     @beartype
     def border_style(self, value: BorderStyle):
-        if isinstance(value, List):
-            value = " ".join(value)
-        self._set_attr("borderStyle", value)
+        self._set_value_or_list_attr("borderStyle", value, " ")
 
     # border_width
     @property
     def border_width(self):
-        return self._get_attr("borderWidth")
+        return self._get_value_or_list_attr("borderWidth", " ")
 
     @border_width.setter
-    def border_width(self, value):
-        self._set_attr("borderWidth", value)
+    @beartype
+    def border_width(self, value: BorderWidth):
+        self._set_value_or_list_attr("borderWidth", value, " ")
 
     # border_color
     @property
     def border_color(self):
-        return self._get_attr("borderColor")
+        return self._get_value_or_list_attr("borderColor", " ")
 
     @border_color.setter
-    def border_color(self, value):
-        self._set_attr("borderColor", value)
+    @beartype
+    def border_color(self, value: BorderColor):
+        self._set_value_or_list_attr("borderColor", value, " ")
 
     # border_radius
     @property
     def border_radius(self):
-        return self._get_attr("borderRadius")
+        return self._get_value_or_list_attr("borderRadius", " ")
 
     @border_radius.setter
-    def border_radius(self, value):
-        self._set_attr("borderRadius", value)
+    @beartype
+    def border_radius(self, value: BorderRadius):
+        self._set_value_or_list_attr("borderRadius", value, " ")
